@@ -18,6 +18,8 @@ foreach my $f (@fields) {
 while ( <STDIN> ) {
     #multiline regex
     undef $/;
+    # remove indent and "boldify" the name
+    s/(\.SH\sUSAGE\n*)(\.IP\n|\s|\.TP\n)([\w\d\\-]*)/$1\\fB$3\\fR/xms;
     # remove colon from the name
     s/(\.TH\s([\w\d-]*)):/$1/gmxs;
     # substitude unrecognized version string with the version
@@ -25,17 +27,22 @@ while ( <STDIN> ) {
     s/([\w\d]*)\:\sunrecognized\soption\s\'\\-\\-version\'/ $version/g;
     # there are no invalid options
     s/([\w\d]*)\:\sinvalid\soption\s--\s\'-\'/$1 $version/g;
-    # strip the header or duplicated body of coverageCount
-    s/\.SH\s(DESCRIPTION|SYNOPSIS).*(Usage:\"?|genome\.\n\.PP)/.SH USAGE\n/gmxs;
     # strip full path
     s/\\fI\\,\/.*\/bin(\/utilities)?\///gmxs;
-    # tidy up help2man removeDuP output:
-    s/Repeated\sRead\sRemoval.*accessible:\s\'\'//xms;
+    # strip the header
+    s/\.SH\s(DESCRIPTION|SYNOPSIS).*?(Usage:\"?\n(\.IP|\.PP))/.SH USAGE\n\.PP/gmxs;
+    # tidy up help2man removeDup output:
+    s/Repeated\sRead\sRemoval.*?accessible:\s\'\'//gxms;
     s/(.SH\sNAME\n[\w\d-]*):/$1/gxms;
     # remove "./" from examples
     s/(\\\&\.\/)([\w\d-]*)/$2/gxms;
-    # remove indent and "boldify" the name
-    s/(\.SH\sUSAGE\n*)(\.IP\n|\s|\.TP\n)([\w\d\\-]*)/$1\\fB$3\\fR/xms;
     s/removeDup\\\\fR\/\\fP/removeDup\\fR/gmxs;
+    # massaging for coverageCount which displays help twice
+    s/(coverageCount\ Version.*?\n)(.*?)(coverageCount\ Version.*?\n\.IP)/.PP/xms;
+    # boldofy "usage" for coverageCount
+    s/(\.PP\n)(Usage\n\.IP)(\ncoverageCount)/$1.SH USAGE\n.PP $3/xms;
+    s/For\ more\ information\ about\ these\ arguments.*//xms;
+	# remove duplicated parts
+	s/Usage:\n\.IP.*//xms;
     print;
 }
